Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(673)

Unified Diff: ui/views/animation/flood_fill_ink_drop_ripple.h

Issue 1937103003: Rename of InkDropAnimation classes to InkDropRipple. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Removed test_ink_drop_animation_observer.h from views.gyp and doc update. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/animation/flood_fill_ink_drop_ripple.h
diff --git a/ui/views/animation/flood_fill_ink_drop_animation.h b/ui/views/animation/flood_fill_ink_drop_ripple.h
similarity index 82%
rename from ui/views/animation/flood_fill_ink_drop_animation.h
rename to ui/views/animation/flood_fill_ink_drop_ripple.h
index 303f295f0001bfbb9c948a699c5198c3b28fb35e..795ffeb8ab12ed8e57148e00a699a402d7ada715 100644
--- a/ui/views/animation/flood_fill_ink_drop_animation.h
+++ b/ui/views/animation/flood_fill_ink_drop_ripple.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef UI_VIEWS_ANIMATION_FLOOD_FILL_INK_DROP_ANIMATION_H_
-#define UI_VIEWS_ANIMATION_FLOOD_FILL_INK_DROP_ANIMATION_H_
+#ifndef UI_VIEWS_ANIMATION_FLOOD_FILL_INK_DROP_RIPPLE_H_
+#define UI_VIEWS_ANIMATION_FLOOD_FILL_INK_DROP_RIPPLE_H_
#include <memory>
#include <string>
@@ -17,8 +17,8 @@
#include "ui/gfx/geometry/point.h"
#include "ui/gfx/geometry/size.h"
#include "ui/gfx/transform.h"
-#include "ui/views/animation/ink_drop_animation.h"
#include "ui/views/animation/ink_drop_painted_layer_delegates.h"
+#include "ui/views/animation/ink_drop_ripple.h"
#include "ui/views/animation/ink_drop_state.h"
#include "ui/views/views_export.h"
@@ -30,10 +30,10 @@ namespace views {
class CircleLayerDelegate;
namespace test {
-class FloodFillInkDropAnimationTestApi;
+class FloodFillInkDropRippleTestApi;
} // namespace test
// An ink drop animation that starts as a small circle and flood fills a
// rectangle of the given size. The circle is clipped to the rectangles bounds.
//
// The valid InkDropState transitions are defined below:
@@ -46,22 +46,22 @@ class FloodFillInkDropAnimationTestApi;
// {All InkDropStates} => ACTIVATED
// {All InkDropStates} => DEACTIVATED
//
-class VIEWS_EXPORT FloodFillInkDropAnimation : public InkDropAnimation {
+class VIEWS_EXPORT FloodFillInkDropRipple : public InkDropRipple {
public:
- FloodFillInkDropAnimation(const gfx::Rect& clip_bounds,
- const gfx::Point& center_point,
- SkColor color);
- ~FloodFillInkDropAnimation() override;
+ FloodFillInkDropRipple(const gfx::Rect& clip_bounds,
+ const gfx::Point& center_point,
+ SkColor color);
+ ~FloodFillInkDropRipple() override;
- // InkDropAnimation:
+ // InkDropRipple:
void SnapToActivated() override;
ui::Layer* GetRootLayer() override;
bool IsVisible() const override;
private:
- friend class test::FloodFillInkDropAnimationTestApi;
+ friend class test::FloodFillInkDropRippleTestApi;
- // InkDropAnimation:
+ // InkDropRipple:
void AnimateStateChange(InkDropState old_ink_drop_state,
InkDropState new_ink_drop_state,
ui::LayerAnimationObserver* observer) override;
@@ -122,9 +122,9 @@ class VIEWS_EXPORT FloodFillInkDropAnimation : public InkDropAnimation {
// The current ink drop state.
InkDropState ink_drop_state_;
- DISALLOW_COPY_AND_ASSIGN(FloodFillInkDropAnimation);
+ DISALLOW_COPY_AND_ASSIGN(FloodFillInkDropRipple);
};
} // namespace views
-#endif // UI_VIEWS_ANIMATION_FLOOD_FILL_INK_DROP_ANIMATION_H_
+#endif // UI_VIEWS_ANIMATION_FLOOD_FILL_INK_DROP_RIPPLE_H_
« no previous file with comments | « ui/views/animation/flood_fill_ink_drop_animation.cc ('k') | ui/views/animation/flood_fill_ink_drop_ripple.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -30,10 +30,10 @@ namespace views {
} // namespace test
-// An ink drop animation that starts as a small circle and flood fills a
+// An ink drop ripple that starts as a small circle and flood fills a
// rectangle of the given size. The circle is clipped to the rectangles bounds.
//
This is Rietveld 408576698